==> scantailor-0.2.7.tar.gz: scantailor-0.2.7/filters/output/RenderParams.cpp <==
/*
    Scan Tailor - Interactive post-processing tool for scanned pages.
    Copyright (C)  Joseph Artsimovich <joseph.artsimovich@gmail.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "RenderParams.h"
#include "ColorParams.h"
#include "ColorGrayscaleOptions.h"
#include "DespeckleLevel.h"

namespace output
{

RenderParams::RenderParams(ColorParams const& cp)
:	m_mask(0)
{
	switch (cp.colorMode()) {
		case ColorParams::BLACK_AND_WHITE:
			m_mask |= WHITE_MARGINS|NORMALIZE_ILLUMINATION
					|NEED_BINARIZATION;
			break;

        case ColorParams::MIXED: {
            m_mask |= NEED_BINARIZATION|MIXED_OUTPUT;

            const ColorGrayscaleOptions& opt = cp.colorGrayscaleOptions();            

            if (opt.autoLayerEnabled()) {
                m_mask |= AUTO_LAYER;
            }

            if (opt.pictureZonesLayerEnabled()) {
                m_mask |= PICTURE_ZONES_LAYER;
            }

            if (opt.foregroundLayerEnabled()) {
                m_mask |= FOREGROUND_LAYER;
            }
            }

            // MOTE: continue to COLOR_GRAYSCALE to get colorGrayscaleOptions

		case ColorParams::COLOR_GRAYSCALE: {
            ColorGrayscaleOptions const opt(
                cp.colorGrayscaleOptions()
            );
			if (opt.whiteMargins()) {
				m_mask |= WHITE_MARGINS;
				if (opt.normalizeIllumination()) {
					m_mask |= NORMALIZE_ILLUMINATION;
				}
			}
			break;
       }

    }
}

} // namespace output

==> scantailor_0.9.7.2.orig.tar.gz: scantailor-0.9.7.2/filters/output/RenderParams.cpp <==
/*
    Scan Tailor - Interactive post-processing tool for scanned pages.
    Copyright (C) 2007-2008  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "RenderParams.h"
#include "ColorParams.h"
#include "ColorGrayscaleOptions.h"

namespace output
{

RenderParams::RenderParams(ColorParams const& cp)
:	m_mask(0)
{
	switch (cp.colorMode()) {
		case ColorParams::BLACK_AND_WHITE:
			m_mask |= WHITE_MARGINS|NORMALIZE_ILLUMINATION
					|NEED_BINARIZATION;
			if (cp.blackWhiteOptions().despeckle()) {
				m_mask |= DESPECKLE;
			}
			break;
		case ColorParams::COLOR_GRAYSCALE: {
			ColorGrayscaleOptions const opt(
				cp.colorGrayscaleOptions()
			);
			if (opt.whiteMargins()) {
				m_mask |= WHITE_MARGINS;
				if (opt.normalizeIllumination()) {
					m_mask |= NORMALIZE_ILLUMINATION;
				}
			}
			break;
		}
		case ColorParams::MIXED:
			m_mask |= WHITE_MARGINS|NORMALIZE_ILLUMINATION
					|NEED_BINARIZATION|MIXED_OUTPUT;
			if (cp.blackWhiteOptions().despeckle()) {
				m_mask |= DESPECKLE;
			}
			break;
	}
}

} // namespace output
